@@ -3,11 +3,16 @@ package InfoSys::FreeDB;
 use 5.006;
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use Sys::Hostname;
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -317,4 +322,3 @@ sub create_connection {
     return($conn);
 }
 
-1;
