@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Connection );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use IO::Socket::INET;
 use InfoSys::FreeDB::Connection qw(:line_parse);
@@ -26,7 +27,11 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -354,7 +359,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -502,7 +507,7 @@ sub _wait_write_reply {
 
     # Check if connection is defined
     defined( $self->get__connection_() ) ||
-        throw Error::Simple("ERROR: InfoSys::FreeDB::Connection::CDDBP::_wait_command_reply, not connected.");
+        throw Error::Simple("ERROR: InfoSys::FreeDB::Connection::CDDBP::_wait_write_reply, not connected.");
 
     # Set blocking
     $self->get__connection_->blocking(1);
@@ -517,7 +522,7 @@ sub _wait_write_reply {
     $head =~ s/^\s+//;
     my ($code) = $head =~ /(\d{3})/;
     exists($rx->{$code}) ||
-        throw Error::Simple("ERROR: InfoSys::FreeDB::Connection::CDDBP::_wait_command_reply, unknown code '$code' returned.");
+        throw Error::Simple("ERROR: InfoSys::FreeDB::Connection::CDDBP::_wait_write_reply, unknown code '$code' returned.");
 
     # Wait for the final DOT or EOL
     my $content .= $head;
@@ -751,4 +756,3 @@ sub write {
     ) );
 }
 
-1;
