@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Connection );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use LWP::UserAgent;
 
@@ -13,7 +14,11 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -137,7 +142,7 @@ This method is an implementation from package C<InfoSys::FreeDB::Connection>. Co
 
 =item SPEED-UP NOTE
 
-If protocol level C<1> is specified, the C<connect> method tries to use the highest available protocol level. To do so, it queries the FreeDB to find out exaclty which level is supported. On C<HTTP> connections this takes long. To speed up C<HTTP> connections specify a higher C<proto_level> -say C<5> before C<connect()> is called.
+If the C<freedb_host> isn't C<freedb.freedb.org> and protocol level C<1> is specified, the C<connect> method tries to use the highest available protocol level. To do so, it queries the FreeDB to find out exaclty which level is supported. On C<HTTP> connections this takes long. To speed up C<HTTP> connections specify a higher C<proto_level> -say C<5> before C<connect()> is called.
 
 =back
 
@@ -468,6 +473,10 @@ sub connect {
     ( $self->get_proto_level() > 1 ) &&
         return(undef);
 
+    # Return if the freedb_host is "freedb.freedb.org"
+    ( $self->get_freedb_host() eq "freedb.freedb.org" ) &&
+        return(undef);
+
     # Check the stat
     my $stat = $self->stat();
 
@@ -526,4 +535,3 @@ sub write {
     throw Error::Simple ("ERROR: InfoSys::FreeDB::Connection::HTTP::write, this method is not supported over 'HTTP'.");
 }
 
-1;
