@@ -3,6 +3,7 @@ package InfoSys::FreeDB::Entry;
 use 5.006;
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use IO::File;
 
@@ -18,7 +19,7 @@ our $DID_RX = '^\s*DISCID\s*=\s*(\S+)\s*$';
 
 our $DL_ERR = '# Disc length: <length> seconds';
 
-our $DL_RX = '^\s*#\s*Disc\s+length\s*:\s*(\d+)\s+seconds\s*$';
+our $DL_RX = '^\s*#\s*Disc\s+length\s*:\s*(\d+)\s+sec[ond]{0,3}s\s*$';
 
 our $DTITLE_RX = '^\s*DTITLE\s*=(.*)$';
 
@@ -68,7 +69,11 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -429,7 +434,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: November 2003
 
 =head1 AUTHOR
 
@@ -784,7 +789,7 @@ sub mk_discid {
 
     # Make ID out of sum, get_disc_length()-2 and the number of tracks.
     # And call set_discid().
-    $self->set_discid( sprintf("%8x",
+    $self->set_discid( sprintf("%08x",
         ( $sum % 0xff ) << 24 |
         int( $self->get_disc_length() - 2 ) << 8 |
         scalar( @track )
@@ -1191,7 +1196,9 @@ sub write_array_ref {
     push(@array, "#");
 
     # DISCID
-    push( @array, "DISCID=" . ($self->get_discid() || '') );
+    $self->get_discid() ||
+        $self->mk_discid();
+    push( @array, "DISCID=" . ( $self->get_discid() ) );
 
     # DTITLE (Artist / Title)
     push( @array, &_str2db_lines( 'DTITLE=',
@@ -1259,4 +1266,3 @@ sub write_fn {
     $self->write_fh($fh);
 }
 
-1;
