@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
@@ -13,7 +14,11 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -171,7 +176,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -215,8 +220,6 @@ sub new_from_content_ref {
     my ($code, $tail) = $line =~ /$CODE_RX/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Motd::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 210 || $code == 401 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Motd::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     my @tail = split(/\s+/, $tail, 4);
     if ($code == 210) {
@@ -235,7 +238,7 @@ sub new_from_content_ref {
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Motd::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Motd::new_from_content_ref, unknown code '$code' returned. Allowed codes are 210 and 401.");
     }
 
     # Create a new object and return it
@@ -300,4 +303,3 @@ sub set_message_text {
     $self->{InfoSys_FreeDB_Response_Motd}{message_text} = $val;
 }
 
-1;
