@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
@@ -25,7 +26,11 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -280,7 +285,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -324,8 +329,6 @@ sub new_from_content_ref {
     my ($code, $tail) = $line =~ /$CODE_RX/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 200 || $code == 211 || $code == 202 || $code == 403 || $code == 409 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     if ($code == 200) {
         my @tail = split(/\s+/, $tail, 3);
@@ -341,6 +344,24 @@ sub new_from_content_ref {
             } ) ],
         );
     }
+    elsif ($code == 210) {
+        pop(@content_ref);
+        my @match = ();
+        foreach my $line (@content_ref) {
+            my @line = split(/\s+/, $line, 3);
+            require InfoSys::FreeDB::Match;
+            push(@match, InfoSys::FreeDB::Match->new( {
+                categ => $line[0],
+                discid => $line[1],
+                dtitle => $line[2],
+            } ) );
+        }
+        %opt = (
+            code => $code,
+            result => 'Found exact matches',
+            match => \@match,
+        );
+    }
     elsif ($code == 211) {
         pop(@content_ref);
         my @match = ();
@@ -380,7 +401,7 @@ sub new_from_content_ref {
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, unknown code '$code' returned. Allowed codes are 200, 210, 211, 202, 403 and 409.");
     }
 
     # Create a new object and return it
@@ -578,4 +599,3 @@ sub unshift_match {
     unshift( @{ $self->{InfoSys_FreeDB_Response_Query}{match} }, @_ );
 }
 
-1;
