@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
@@ -25,7 +26,11 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -192,7 +197,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -236,9 +241,6 @@ sub new_from_content_ref {
     my ($code, $tail) = $line =~ /$CODE_RX/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Read::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 210 || $code == 401 || $code == 402 || $code == 403 ||
-            $code == 409 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Read::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     if ($code == 210) {
         pop( @content_ref);
@@ -296,7 +298,7 @@ sub new_from_content_ref {
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Read::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Read::new_from_content_ref, unknown code '$code' returned. Allowed codes are 210, 211, 401, 402, 403 and 409.");
     }
 
     # Create a new object and return it
@@ -380,4 +382,3 @@ sub set_entry {
     $self->{InfoSys_FreeDB_Response_Read}{entry} = $val;
 }
 
-1;
