@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
@@ -15,7 +16,11 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -206,7 +211,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -250,9 +255,6 @@ sub new_from_content_ref {
     my ($code, $tail) = $line =~ /$CODE_RX/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::SignOn::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 200 || $code == 201 || $code == 432 || $code == 433 ||
-            $code == 434 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::SignOn::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     my @tail = split(/\s+/, $tail, 7);
     if ($code == 200) {
@@ -311,7 +313,7 @@ sub new_from_content_ref {
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::SignOn::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::SignOn::new_from_content_ref, unknown code '$code' returned. Allowed codes are 200, 201, 432, 433 and 434.");
     }
 
     # Create a new object and return it
@@ -471,4 +473,3 @@ sub set_write_allowed {
     }
 }
 
-1;
