@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 our $STAT_DB_ENTRIES_RX = '^\s*database\s+entries\s*:\s*(\S+)';
@@ -27,7 +28,11 @@ our $STAT_USERS_CUR_RX = '^\s*current\s+users\s*:\s*(\S+)';
 our $STAT_USERS_MAX_RX = '^\s*max\s+users\s*:\s*(\S+)';
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -281,7 +286,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -325,8 +330,6 @@ sub new_from_content_ref {
     my ($code) = $line =~ /^\s*(\d{3})\s/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Stat::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 210 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Stat::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     if ($code == 210) {
         pop(@content_ref);
@@ -377,7 +380,7 @@ sub new_from_content_ref {
         }
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Stat::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Stat::new_from_content_ref, unknown code '$code' returned. Allowed code is 210.");
     }
 
     # Create a new object and return it
@@ -627,4 +630,3 @@ sub set_users_max {
     $self->{InfoSys_FreeDB_Response_Stat}{users_max} = $val;
 }
 
-1;
