@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Used by _initialize
@@ -12,7 +13,11 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -158,7 +163,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -202,8 +207,6 @@ sub new_from_content_ref {
     my ($code) = $line =~ /^\s*(\d{3})\s/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Whom::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 210 || $code == 401 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Whom::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     if ($code == 210) {
         pop(@content_ref);
@@ -221,7 +224,7 @@ sub new_from_content_ref {
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Whom::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Whom::new_from_content_ref, unknown code '$code' returned. Allowed codes are 210 and 401.");
     }
 
     # Create a new object and return it
@@ -266,4 +269,3 @@ sub set_message_text {
     $self->{InfoSys_FreeDB_Response_Whom}{message_text} = $val;
 }
 
-1;
