@@ -4,11 +4,16 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -151,7 +156,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -195,8 +200,6 @@ sub new_from_content_ref {
     my ($code, $tail) = $line =~ /$CODE_RX/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Write::1::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 320 || $code == 401 || $code == 402 || $code == 409 || $code == 501 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Write::1::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     if ($code == 320) {
         my @tail = split(/\s+/, $tail, 2);
@@ -236,7 +239,7 @@ sub new_from_content_ref {
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Write::1::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Write::1::new_from_content_ref, unknown code '$code' returned. Allowed codes are 320, 401, 402, 409 and 501.");
     }
 
     # Create a new object and return it
@@ -301,4 +304,3 @@ sub set_discid {
     $self->{InfoSys_FreeDB_Response_Write_1}{discid} = $val;
 }
 
-1;
