@@ -4,11 +4,16 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
 # Package version
-our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.91 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -139,7 +144,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: October 2003
+Last update: December 2003
 
 =head1 AUTHOR
 
@@ -183,8 +188,6 @@ sub new_from_content_ref {
     my ($code, $tail) = $line =~ /$CODE_RX/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Write::2::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 200 || $code == 401 ||
-        throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Write::2::new_from_content_ref, first line of specified \'content_ref\' does not contain a valid code.');
     my %opt;
     if ($code == 200) {
         my @tail = split(/\s+/, $tail, 2);
@@ -203,7 +206,7 @@ sub new_from_content_ref {
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Write::2::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Write::2::new_from_content_ref, unknown code '$code' returned. Allowed codes are 200 and 401.");
     }
 
     # Create a new object and return it
@@ -248,4 +251,3 @@ sub set_message {
     $self->{InfoSys_FreeDB_Response_Write_2}{message} = $val;
 }
 
-1;
